// Motion Master stepper motor seems commands are sent through base address + 1

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <unistd.h>
#include <fcntl.h>
#include <Application.h>
#include "mm2000.h"
#include "motion_master.h"

// constructor
motion_master::motion_master(void)
{
	h_MM = 0;
}

// destructor
motion_master::~motion_master(void)
{
	Close();
}

// open handle to mm always call first arg is board base address
bool motion_master::Open( int32 mm_address )
{
	int32 address;

	h_MM = open("/dev/misc/mm2000", O_RDWR );
	if( h_MM == -1 )
	{
		perror("Open");
		Close();
		return false;
	}
	else
	{
		address = mm_address+0;
		if( ( ioctl( h_MM, MM2000_LOAD_ADDRESS, &address ) ) == -1 )
		{
			perror("Open - Loading MM Register Address");
			Close();
			return false;
		}
	}
	
	return true;
}

// close handle only call this as last operation or allow delete to call it for you
void motion_master::Close(void)
{
	if( h_MM ) close(h_MM);
	h_MM = 0;
}

// write ascii command to mm2000
bool motion_master::Send( char *cmd )
{
	int rslt = write( h_MM, cmd, strlen(cmd) ); 
	if( rslt == -1 )
	{
		perror("MM_outp");
		return false;
	}

	return true;
}

// read into buffer resp  length is max length to read
bool motion_master::Read( char *resp, int32 length )
{
	int rslt = read( h_MM, (void*)resp, length ); 
	if( rslt == -1 )
	{
		perror("MM_inp");
		return false;
	}
	return true;
}

bool motion_master::MoveTo( int32 axis, int32 pos )
{
     char cmd[32];
     sprintf(cmd,"%dPA%d\r",axis, pos );
     Send( cmd );
}

int32 motion_master::Where( int32 axis )
{
	char response[256];
	char cmd[32];
	int32 cpos;

    sprintf(cmd,"%dTP\r",axis );
    Send( cmd );
    Read( response, 255 );

    if( 1 != sscanf(response,"%ld",&cpos ) )
    {
        printf("pos response scan error\n%s\n\n",response);
    }

	return cpos;
}
